@@ -1,10 +1,20 @@
-/* $Id: rolodex.c,v 1.24 2013/09/01 22:03:44 tom Exp $ */
+/* $Id: rolodex.c,v 1.28 2016/11/20 19:54:51 tom Exp $ */
 #include "rolodex.h"
 
 #ifdef HAVE_XCURSES
 char *XCursesProgramName = "rolodex";
 #endif
 
+#define MYSIZE 256
+static void fmt1s (char *target, const char *format, const char *source)
+{
+   int limit = MYSIZE - (int)(strlen (format) + strlen (source));
+   if (limit > 0)
+      sprintf (target, format, limit, source);
+   else
+      *target = '\0';
+}
+
 /*
  * This is the main part of the loop.
  */
@@ -18,9 +28,9 @@ int main (void)
    WINDOW *cursesWin;
    const char *menulist[MAX_MENU_ITEMS][MAX_SUB_ITEMS];
    const char *title[5];
-   char *home, temp[256];
+   char *home, temp[MYSIZE];
    const char *mesg[15];
-   int subMenuSize[10], menuLocations[10], selection;
+   int subMenuSize[10], menuLocations[10];
    int group, ret, x;
    int groupCount = 0;
 
@@ -69,7 +79,7 @@ int main (void)
    title[0] = "<C></U>Cdk Rolodex";
    title[1] = "<C></B/24>Written by Mike Glover";
    rolodexTitle = newCDKLabel (cdkscreen, CENTER, CENTER,
-			       (CDK_CSTRING2) title, 2,
+			       (CDK_CSTRING2)title, 2,
 			       FALSE, FALSE);
 
    /* Define the help key binding. */
@@ -83,13 +93,13 @@ int main (void)
    if (home != 0)
    {
       /* Make sure the $HOME/.rolodex directory exists. */
-      sprintf (temp, "%s/.rolodex", home);
+      fmt1s (temp, "%.*s/.rolodex", home);
 
       /* Set the value of the global rolodex DBM directory. */
       GDBMDir = copyChar (temp);
 
       /* Set the value of the global RC filename. */
-      sprintf (temp, "%s/.rolorc", home);
+      fmt1s (temp, "%.*s/.rolorc", home);
       GRCFile = copyChar (temp);
    }
    else
@@ -115,18 +125,18 @@ int main (void)
    if (groupCount < 0)
    {
       /* The RC file seems to be corrupt. */
-      sprintf (temp, "<C></B/16>The RC file (%s) seems to be corrupt.", GRCFile);
+      fmt1s (temp, "<C></B/16>The RC file (%.*s) seems to be corrupt.", GRCFile);
       mesg[0] = temp;
       mesg[1] = "<C></B/16>No rolodex groups were loaded.";
       mesg[2] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 3);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 3);
       groupCount = 0;
    }
    else if (groupCount == 0)
    {
       mesg[0] = "<C></B/24>Empty rolodex RC file. No groups loaded.";
       mesg[1] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 2);
    }
    else
    {
@@ -141,14 +151,14 @@ int main (void)
       }
       mesg[0] = temp;
       mesg[1] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 2);
    }
 
    /* Loop until we are done. */
    for (;;)
    {
       /* Activate the menu */
-      selection = activateCDKMenu (rolodexMenu, 0);
+      int selection = activateCDKMenu (rolodexMenu, 0);
 
       /* Check the return value of the selection. */
       if (selection == 0)
@@ -231,8 +241,8 @@ int main (void)
 
 	    /* Add the group if they said yes. */
 	    if (popupDialog (cdkscreen,
-			     (CDK_CSTRING2) mesg, 2,
-			     (CDK_CSTRING2) buttons, 2) == 0)
+			     (CDK_CSTRING2)mesg, 2,
+			     (CDK_CSTRING2)buttons, 2) == 0)
 	    {
 	       groupCount = addRolodexGroup (cdkscreen, groupList, groupCount);
 	    }
@@ -287,7 +297,7 @@ int main (void)
 int writeRCFile (CDKSCREEN *screen, char *filename, SRolodex * groupList, int groupCount)
 {
    char *mesg[5];
-   char temp[256];
+   char temp[MYSIZE];
    time_t clck;
    FILE *fd;
    int x;
@@ -295,17 +305,17 @@ int writeRCFile (CDKSCREEN *screen, char *filename, SRolodex * groupList, int gr
    /* Can we open the file?                                     */
    if ((fd = fopen (filename, "w")) == 0)
    {
-      sprintf (temp, "</B/16>The file <%s> could not be opened.", filename);
+      fmt1s (temp, "</B/16>The file <%.*s> could not be opened.", filename);
       mesg[0] = copyChar (temp);
 #ifdef HAVE_STRERROR
-      sprintf (temp, "<C></B/16>%s", strerror (errno));
+      fmt1s (temp, "<C></B/16>%.*s", strerror (errno));
 #else
       sprintf (temp, "<C></B/16>Unknown reason.");
 #endif
       mesg[1] = copyChar (temp);
       mesg[2] = copyChar ("<C>Press any key to continue.");
 
-      popupLabel (screen, (CDK_CSTRING2) mesg, 3);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 3);
 
       freeCharList (mesg, 3);
 
@@ -342,11 +352,11 @@ int writeRCFile (CDKSCREEN *screen, char *filename, SRolodex * groupList, int gr
       mesg[0] = copyChar (temp);
    }
 
-   sprintf (temp, "<C>%s", filename);
+   fmt1s (temp, "<C>%.*s", filename);
    mesg[1] = copyChar (temp);
    mesg[2] = copyChar ("<C>Press any key to continue.");
 
-   popupLabel (screen, (CDK_CSTRING2) mesg, 3);
+   popupLabel (screen, (CDK_CSTRING2)mesg, 3);
 
    freeCharList (mesg, 3);
    return (1);
@@ -364,7 +374,7 @@ int pickRolodexGroup (CDKSCREEN *screen,
    CDKSCROLL *roloList  = 0;
    int height           = groupCount;
    char *mesg[MAXGROUPS];
-   char temp[256];
+   char temp[MYSIZE];
    int selection, x;
 
    /* Determine the height of the scrolling list. */
@@ -377,14 +387,14 @@ int pickRolodexGroup (CDKSCREEN *screen,
    /* Copy the names of the scrolling list into an array. */
    for (x = 0; x < groupCount; x++)
    {
-      sprintf (temp, "<C></B/29>%s", groupList[x].name);
+      fmt1s (temp, "<C></B/29>%.*s", groupList[x].name);
       mesg[x] = copyChar (temp);
    }
 
    /* Create the scrolling list. */
    roloList = newCDKScroll (screen, CENTER, CENTER, NONE,
 			    height, 50, title,
-			    (CDK_CSTRING2) mesg, groupCount,
+			    (CDK_CSTRING2)mesg, groupCount,
 			    NONUMBERS, A_REVERSE, TRUE, FALSE);
 
    /* Create a callback to the scrolling list. */
@@ -412,7 +422,7 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    const char *mesg[4];
    char *desc;
    char *newGroupName;
-   char temp[256];
+   char temp[MYSIZE];
    int x;
 
    /* Create the name widget. */
@@ -420,7 +430,7 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 			  "<C></B/29>New Group Name",
 			  "</B/29>   Name: ",
 			  A_NORMAL, '_', vMIXED,
-			  20, 2, 256, TRUE, FALSE);
+			  20, 2, MYSIZE, TRUE, FALSE);
 
 
    /* Get the name. */
@@ -431,7 +441,7 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       mesg[0] = "<C></B/16>Add Group Canceled.";
       destroyCDKEntry (newName);
-      popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 1);
       return groupCount;
    }
 
@@ -440,9 +450,9 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       if (strcmp (newGroupName, groupList[x].name) == 0)
       {
-	 sprintf (temp, "<C></B/16>Sorry the group (%s) already exists.", newGroupName);
+	 fmt1s (temp, "<C></B/16>Sorry the group (%.*s) already exists.", newGroupName);
 	 mesg[0] = temp;
-	 popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+	 popupLabel (screen, (CDK_CSTRING2)mesg, 1);
 	 destroyCDKEntry (newName);
 	 return groupCount;
       }
@@ -456,7 +466,7 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 			  "<C></B/29>Group Description",
 			  "</B/29>Descriprion: ",
 			  A_NORMAL, '_', vMIXED,
-			  20, 2, 256, TRUE, FALSE);
+			  20, 2, MYSIZE, TRUE, FALSE);
 
    /* Get the description. */
    desc = activateCDKEntry (newDesc, 0);
@@ -491,18 +501,18 @@ int addRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 void displayRolodexStats (CDKSCREEN *screen, int groupCount)
 {
    /* Declare local variables. */
-   char *mesg[6], temp[256];
+   char *mesg[6], temp[MYSIZE];
 
    /* Create the information to display. */
    sprintf (temp, "<C></U>Rolodex Statistics");
    mesg[0] = copyChar (temp);
-   sprintf (temp, "</B/5>Read Command Filename<!B!5> </U>%s<!U>", GRCFile);
+   fmt1s (temp, "</B/5>Read Command Filename<!B!5> </U>%.*s<!U>", GRCFile);
    mesg[1] = copyChar (temp);
    sprintf (temp, "</B/5>Group Count          <!B!5> </U>%d<!U>", groupCount);
    mesg[2] = copyChar (temp);
 
    /* Display the message. */
-   popupLabel (screen, (CDK_CSTRING2) mesg, 3);
+   popupLabel (screen, (CDK_CSTRING2)mesg, 3);
 
    freeCharList (mesg, 3);
 }
@@ -523,7 +533,7 @@ int writeRCFileAs (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 			    "<C></R>Save As",
 			    "Filename: ",
 			    A_NORMAL, '_', vMIXED,
-			    20, 2, 256, TRUE, FALSE);
+			    20, 2, MYSIZE, TRUE, FALSE);
 
    /* Add a pre-process function so no spaces are introduced. */
    setCDKEntryPreProcess (newRCFile, entryPreProcessCB, 0);
@@ -562,7 +572,7 @@ int openNewRCFile (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 {
    /* Declare local variables. */
    CDKFSELECT *fileSelector;
-   char *filename, *mesg[10], temp[256];
+   char *filename, *mesg[10];
    int x;
 
    /* Get the filename. */
@@ -581,7 +591,7 @@ int openNewRCFile (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       destroyCDKFselect (fileSelector);
       mesg[0] = copyChar ("Open New RC File Aborted.");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 1);
       freeCharList (mesg, 1);
       return groupCount;
    }
@@ -600,13 +610,15 @@ int openNewRCFile (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    /* Check the return value. */
    if (groupCount < 0)
    {
+      char temp[MYSIZE];
+
       /* This file does not appear to be a rolodex file. */
       mesg[0] = copyChar ("<C></B/16>The file<!B!16>");
-      sprintf (temp, "<C></B/16>(%s)<!B!16>", filename);
+      fmt1s (temp, "<C></B/16>(%.*s)<!B!16>", filename);
       mesg[1] = copyChar (temp);
       mesg[2] = copyChar ("<C>does not seem to be a rolodex RC file.");
       mesg[3] = copyChar ("<C>Press any key to continue.");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 4);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 4);
       freeCharList (mesg, 4);
       groupCount = 0;
    }
@@ -649,7 +661,7 @@ int readRCFile (char *filename, SRolodex * groupList)
       if (strlen (lines[x]) != 0 && lines[x][0] != '#')
       {
 	 items = CDKsplitString (lines[x], CTRL ('V'));
-	 chunks = (int)CDKcountStrings ((CDK_CSTRING2) items);
+	 chunks = (int)CDKcountStrings ((CDK_CSTRING2)items);
 
 	 /* Only take the ones which fit the format. */
 	 if (chunks == 3)
@@ -697,11 +709,10 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
    CDKSCROLL *nameList  = 0;
    CDKLABEL *helpWindow = 0;
    SPhoneData phoneData;
-   SPhoneRecord *phoneRecord;
    char *Index[MAX_ITEMS];
    const char *title[3];
    const char *mesg[3];
-   char temp[256];
+   char temp[MYSIZE];
    int phoneCount, selection, height, x;
 
    /* Set up the help window at the bottom of the screen. */
@@ -710,7 +721,7 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
    title[1]     = "<C>Press </B>?<!B> to get detailed help.";
    title[2]     = "<C><#HL(30)>";
    helpWindow   = newCDKLabel (screen, CENTER, BOTTOM,
-			       (CDK_CSTRING2) title, 3,
+			       (CDK_CSTRING2)title, 3,
 			       FALSE, FALSE);
    drawCDKLabel (helpWindow, FALSE);
 
@@ -733,8 +744,8 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
       mesg[0] = "<C>There were no entries in this group.";
       mesg[1] = "<C>Do you want to add a new listng?";
       if (popupDialog (screen,
-		       (CDK_CSTRING2) mesg, 2,
-		       (CDK_CSTRING2) buttons, 2) == 1)
+		       (CDK_CSTRING2)mesg, 2,
+		       (CDK_CSTRING2)buttons, 2) == 1)
       {
 	 destroyCDKLabel (helpWindow);
 	 return;
@@ -749,7 +760,7 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
    else if (phoneCount < 0)
    {
       mesg[0] = "<C>Could not open the database for this group.";
-      popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 1);
       destroyCDKLabel (helpWindow);
       return;
    }
@@ -757,17 +768,17 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
    /* Set up the data needed for the scrolling list. */
    for (x = 0; x < phoneData.recordCount; x++)
    {
-      phoneRecord = &phoneData.record[x];
+      SPhoneRecord *phoneRecord = &phoneData.record[x];
       sprintf (temp, "</B/29>%s (%s)", phoneRecord->name, GLineType[phoneRecord->lineType]);
       Index[x] = copyChar (temp);
    }
-   sprintf (temp, "<C>Listing of Group </U>%s", groupName);
+   fmt1s (temp, "<C>Listing of Group </U>%.*s", groupName);
    height = (phoneData.recordCount > 5 ? 8 : phoneData.recordCount + 3);
 
    /* Create the scrolling list. */
    nameList = newCDKScroll (screen, CENTER, CENTER, RIGHT,
 			    height, 50, temp,
-			    (CDK_CSTRING2) Index,
+			    (CDK_CSTRING2)Index,
 			    phoneData.recordCount,
 			    NUMBERS, A_REVERSE, TRUE, FALSE);
 
@@ -804,7 +815,7 @@ void useRolodexGroup (CDKSCREEN *screen, char *groupName, char *groupDesc
       /* Something happened. */
       mesg[0] = "<C>Could not save phone data to data file.";
       mesg[1] = "<C>All changes have been lost.";
-      popupLabel (screen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 2);
    }
 
    /* Clean up. */
@@ -853,7 +864,7 @@ int readPhoneDataFile (char *dataFile, SPhoneData * phoneData)
       {
 	 /* Split the string. */
 	 items = CDKsplitString (lines[x], CTRL ('V'));
-	 chunks = (int)CDKcountStrings ((CDK_CSTRING2) items);
+	 chunks = (int)CDKcountStrings ((CDK_CSTRING2)items);
 
 	 /* Copy the chunks. */
 	 if (chunks == 8)
@@ -893,8 +904,6 @@ int readPhoneDataFile (char *dataFile, SPhoneData * phoneData)
  */
 int savePhoneDataFile (char *filename, SPhoneData * phoneData)
 {
-   /* Declare variables. */
-   SPhoneRecord *phoneRecord;
    time_t clck;
    FILE *fd;
    int x;
@@ -917,8 +926,7 @@ int savePhoneDataFile (char *filename, SPhoneData * phoneData)
    /* Cycle through the data and start writing it to the file. */
    for (x = 0; x < phoneData->recordCount; x++)
    {
-      /* Get a pointer to the object. */
-      phoneRecord = &phoneData->record[x];
+      SPhoneRecord *phoneRecord = &phoneData->record[x];
 
       /* Check the phone type. */
       if (phoneRecord->lineType == vCell || phoneRecord->lineType == vPager)
@@ -953,7 +961,7 @@ int savePhoneDataFile (char *filename, SPhoneData * phoneData)
 void displayPhoneInfo (CDKSCREEN *screen, SPhoneRecord record)
 {
    /* Declare local variables. */
-   char *mesg[10], temp[256];
+   char *mesg[10], temp[MYSIZE];
 
    /* Check the type of line it is. */
    if (record.lineType == vVoice ||
@@ -965,32 +973,32 @@ void displayPhoneInfo (CDKSCREEN *screen, SPhoneRecord record)
        record.lineType == vFAX3)
    {
       /* Create the information to display. */
-      sprintf (temp, "<C></U>%s Phone Record", GLineType[record.lineType]);
+      fmt1s (temp, "<C></U>%.*s Phone Record", GLineType[record.lineType]);
       mesg[0] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Name        <!B!29>%s", record.name);
+      fmt1s (temp, "</B/29>Name        <!B!29>%.*s", record.name);
       mesg[1] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Phone Number<!B!29>%s", record.phoneNumber);
+      fmt1s (temp, "</B/29>Phone Number<!B!29>%.*s", record.phoneNumber);
       mesg[2] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Address     <!B!29>%s", record.address);
+      fmt1s (temp, "</B/29>Address     <!B!29>%.*s", record.address);
       mesg[3] = copyChar (temp);
 
-      sprintf (temp, "</B/29>City        <!B!29>%s", record.city);
+      fmt1s (temp, "</B/29>City        <!B!29>%.*s", record.city);
       mesg[4] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Province    <!B!29>%s", record.province);
+      fmt1s (temp, "</B/29>Province    <!B!29>%.*s", record.province);
       mesg[5] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Postal Code <!B!29>%s", record.postalCode);
+      fmt1s (temp, "</B/29>Postal Code <!B!29>%.*s", record.postalCode);
       mesg[6] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Comment     <!B!29>%s", record.desc);
+      fmt1s (temp, "</B/29>Comment     <!B!29>%.*s", record.desc);
       mesg[7] = copyChar (temp);
 
       /* Pop the information up on the screen. */
-      popupLabel (screen, (CDK_CSTRING2) mesg, 8);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 8);
 
       /* Clean up. */
       freeChar (mesg[0]);
@@ -1005,20 +1013,20 @@ void displayPhoneInfo (CDKSCREEN *screen, SPhoneRecord record)
    else if (record.lineType == vPager || record.lineType == vCell)
    {
       /* Create the information to display. */
-      sprintf (temp, "<C></U>%s Phone Record", GLineType[record.lineType]);
+      fmt1s (temp, "<C></U>%.*s Phone Record", GLineType[record.lineType]);
       mesg[0] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Name        <!B!29>%s", record.name);
+      fmt1s (temp, "</B/29>Name        <!B!29>%.*s", record.name);
       mesg[1] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Phone Number<!B!29>%s", record.phoneNumber);
+      fmt1s (temp, "</B/29>Phone Number<!B!29>%.*s", record.phoneNumber);
       mesg[2] = copyChar (temp);
 
-      sprintf (temp, "</B/29>Comment     <!B!29>%s", record.desc);
+      fmt1s (temp, "</B/29>Comment     <!B!29>%.*s", record.desc);
       mesg[3] = copyChar (temp);
 
       /* Pop the information up on the screen. */
-      popupLabel (screen, (CDK_CSTRING2) mesg, 4);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 4);
 
       freeCharList (mesg, 4);
    }
@@ -1026,7 +1034,7 @@ void displayPhoneInfo (CDKSCREEN *screen, SPhoneRecord record)
    {
       mesg[0] = copyChar ("<C></R>Error<!R> </U>Unknown Phone Line Type");
       mesg[1] = copyChar ("<C>Can not display information.");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 2);
       freeCharList (mesg, 2);
    }
 }
@@ -1053,7 +1061,7 @@ void aboutCdkRolodex (CDKSCREEN *screen)
    mesg[12] = "<C><#HL(35)>";
    mesg[13] = "<R></B/24>March 1996";
 
-   popupLabel (screen, (CDK_CSTRING2) mesg, 14);
+   popupLabel (screen, (CDK_CSTRING2)mesg, 14);
 }
 
 /*
@@ -1064,7 +1072,7 @@ int deleteRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    /* Declare local variables. */
    char *mesg[10];
    const char *buttons[5];
-   char temp[256];
+   char temp[MYSIZE];
    int selection, choice, x;
 
    /* If there are no groups, pop up a message telling them. */
@@ -1072,7 +1080,7 @@ int deleteRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       mesg[0] = copyChar ("<C>Error");
       mesg[1] = copyChar ("<C>There as no groups defined.");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 2);
       freeCharList (mesg, 2);
 
       /* Return the current group count. */
@@ -1089,7 +1097,7 @@ int deleteRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       mesg[0] = copyChar ("<C>   Delete Canceled   ");
       mesg[1] = copyChar ("<C>No Group Deleted");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 2);
       freeCharList (mesg, 2);
       return groupCount;
    }
@@ -1097,13 +1105,13 @@ int deleteRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    /* Let's make sure they want to delete the group. */
    mesg[0] = copyChar ("<C></U>Confirm Delete");
    mesg[1] = copyChar ("<C>Are you sure you want to delete the group");
-   sprintf (temp, "<C></R>%s<!R>?", groupList[selection].name);
+   fmt1s (temp, "<C></R>%.*s<!R>?", groupList[selection].name);
    mesg[2] = copyChar (temp);
    buttons[0] = "<No>";
    buttons[1] = "<Yes>";
    choice = popupDialog (screen,
-			 (CDK_CSTRING2) mesg, 3,
-			 (CDK_CSTRING2) buttons, 2);
+			 (CDK_CSTRING2)mesg, 3,
+			 (CDK_CSTRING2)buttons, 2);
    freeCharList (mesg, 3);
 
    /* Check the results of the confirmation. */
@@ -1111,7 +1119,7 @@ int deleteRolodexGroup (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    {
       mesg[0] = copyChar ("<C>   Delete Canceled   ");
       mesg[1] = copyChar ("<C>No Group Deleted");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 2);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 2);
       freeCharList (mesg, 2);
       return groupCount;
    }
@@ -1147,7 +1155,7 @@ int addPhoneRecord (CDKSCREEN *screen, SPhoneData * phoneData)
    SPhoneRecord *phoneRecord;
    const char *titleMesg[3];
    char *types[GLINETYPECOUNT];
-   char temp[256];
+   char temp[MYSIZE];
    int ret, x;
    int myType;
 
@@ -1157,14 +1165,14 @@ int addPhoneRecord (CDKSCREEN *screen, SPhoneData * phoneData)
    /* Create a title label to display. */
    titleMesg[0] = "<C></B/16>Add New Phone Record";
    title = newCDKLabel (screen, CENTER, TOP,
-			(CDK_CSTRING2) titleMesg, 1,
+			(CDK_CSTRING2)titleMesg, 1,
 			FALSE, FALSE);
    drawCDKLabel (title, FALSE);
 
    /* Create the phone line type list. */
    for (x = 0; x < GLINETYPECOUNT; x++)
    {
-      sprintf (temp, "<C></U>%s", GLineType[x]);
+      fmt1s (temp, "<C></U>%.*s", GLineType[x]);
       types[x] = copyChar (temp);
    }
 
@@ -1172,7 +1180,7 @@ int addPhoneRecord (CDKSCREEN *screen, SPhoneData * phoneData)
    itemList = newCDKItemlist (screen, CENTER, CENTER,
 			      "<C>What Type Of Line Is It?",
 			      "Type: ",
-			      (CDK_CSTRING2) types, GLINETYPECOUNT, 0,
+			      (CDK_CSTRING2)types, GLINETYPECOUNT, 0,
 			      TRUE, FALSE);
    myType = activateCDKItemlist (itemList, 0);
    phoneRecord->lineType = (ELineType) myType;
@@ -1223,33 +1231,32 @@ int getLargePhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
    CDKTEMPLATE *phoneTemplate;
    const char *buttons[5];
    const char *mesg[15];
-   int ret;
 
    /* Define the widgets. */
    nameEntry = newCDKEntry (screen, LEFT, 5,
 			    0, "</B/5>Name: ",
 			    A_NORMAL,
-			    '_', vMIXED, 20, 2, 256,
+			    '_', vMIXED, 20, 2, MYSIZE,
 			    TRUE, FALSE);
    addressEntry = newCDKEntry (screen, RIGHT, 5,
 			       0, "</B/5>Address: ",
 			       A_NORMAL,
-			       '_', vMIXED, 40, 2, 256,
+			       '_', vMIXED, 40, 2, MYSIZE,
 			       TRUE, FALSE);
    cityEntry = newCDKEntry (screen, LEFT, 8,
 			    0, "</B/5>City: ",
 			    A_NORMAL,
-			    '_', vMIXED, 20, 2, 256,
+			    '_', vMIXED, 20, 2, MYSIZE,
 			    TRUE, FALSE);
    provEntry = newCDKEntry (screen, 29, 8,
 			    0, "</B/5>Province: ",
 			    A_NORMAL,
-			    '_', vMIXED, 15, 2, 256,
+			    '_', vMIXED, 15, 2, MYSIZE,
 			    TRUE, FALSE);
    postalEntry = newCDKEntry (screen, RIGHT, 8,
 			      0, "</B/5>Postal Code: ",
 			      A_NORMAL,
-			      '_', vUMIXED, 8, 2, 256,
+			      '_', vUMIXED, 8, 2, MYSIZE,
 			      TRUE, FALSE);
    phoneTemplate = newCDKTemplate (screen, LEFT, 11,
 				   0,
@@ -1261,12 +1268,14 @@ int getLargePhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
 			    0,
 			    "</B/5>Description: ",
 			    A_NORMAL,
-			    '_', vMIXED, 20, 2, 256,
+			    '_', vMIXED, 20, 2, MYSIZE,
 			    TRUE, FALSE);
 
    /* Get the phone information. */
    for (;;)
    {
+      int ret;
+
       /* Draw the widgets on the screen. */
       drawCDKEntry (nameEntry, ObjOf (nameEntry)->box);
       drawCDKEntry (addressEntry, ObjOf (addressEntry)->box);
@@ -1294,8 +1303,8 @@ int getLargePhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
       buttons[1] = "</B/16><Cancel>";
       buttons[2] = "</B/32><Modify Information>";
       ret = popupDialog (screen,
-			 (CDK_CSTRING2) mesg, 2,
-			 (CDK_CSTRING2) buttons, 3);
+			 (CDK_CSTRING2)mesg, 2,
+			 (CDK_CSTRING2)buttons, 3);
 
       /* Check the response of the popup dialog box. */
       if (ret == 0)
@@ -1348,18 +1357,16 @@ int getLargePhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
  */
 int getSmallPhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
 {
-   /* Declare local variables. */
    CDKENTRY *nameEntry, *descEntry;
    CDKTEMPLATE *phoneTemplate;
    const char *buttons[5];
    const char *mesg[15];
-   int ret;
 
    /* Define the widgets. */
    nameEntry = newCDKEntry (screen, CENTER, 8,
 			    0, "</B/5>Name: ",
 			    A_NORMAL,
-			    '_', vMIXED, 20, 2, 256,
+			    '_', vMIXED, 20, 2, MYSIZE,
 			    TRUE, FALSE);
    phoneTemplate = newCDKTemplate (screen, CENTER, 11,
 				   0, "</B/5>Number: ",
@@ -1369,12 +1376,14 @@ int getSmallPhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
    descEntry = newCDKEntry (screen, CENTER, 14,
 			    0, "</B/5>Description: ",
 			    A_NORMAL,
-			    '_', vMIXED, 20, 2, 256,
+			    '_', vMIXED, 20, 2, MYSIZE,
 			    TRUE, FALSE);
 
    /* Get the phone information. */
    for (;;)
    {
+      int ret;
+
       /* Draw the widgets on the screen. */
       drawCDKEntry (nameEntry, ObjOf (nameEntry)->box);
       drawCDKTemplate (phoneTemplate, ObjOf (phoneTemplate)->box);
@@ -1398,8 +1407,8 @@ int getSmallPhoneRecord (CDKSCREEN *screen, SPhoneRecord * phoneRecord)
       buttons[1] = "</B/16><Cancel>";
       buttons[2] = "</B/8><Modify Information>";
       ret = popupDialog (screen,
-			 (CDK_CSTRING2) mesg, 2,
-			 (CDK_CSTRING2) buttons, 3);
+			 (CDK_CSTRING2)mesg, 2,
+			 (CDK_CSTRING2)buttons, 3);
 
       /* Check the response of the popup dialog box. */
       if (ret == 0)
@@ -1449,7 +1458,7 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    CDKSELECTION *selectionList;
    CDKENTRY *entry;
    CDKLABEL *title;
-   char *itemList[MAX_ITEMS], *mesg[10], temp[256];
+   char *itemList[MAX_ITEMS], *mesg[10], temp[MYSIZE];
    const char *choices[] =
    {
       "Print to Printer ",
@@ -1479,8 +1488,8 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
    selectionList = newCDKSelection (screen, CENTER, CENTER, RIGHT,
 				    height, 40,
 				    "<C></U>Select Which Groups To Print",
-				    (CDK_CSTRING2) itemList, groupCount,
-				    (CDK_CSTRING2) choices, 3,
+				    (CDK_CSTRING2)itemList, groupCount,
+				    (CDK_CSTRING2)choices, 3,
 				    A_REVERSE, TRUE, FALSE);
 
    /* Activate the selection list. */
@@ -1489,7 +1498,7 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
       /* Tell the user they exited early. */
       destroyCDKSelection (selectionList);
       mesg[0] = copyChar ("<C>Print Canceled.");
-      popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+      popupLabel (screen, (CDK_CSTRING2)mesg, 1);
 
       freeCharList (mesg, 1);
       freeCharList (itemList, (unsigned)groupCount);
@@ -1503,11 +1512,11 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
       if (selectionList->selections[x] == 0)
       {
 	 /* Create a title. */
-	 sprintf (temp, "<C></R>Printing Group [%s] to Printer",
-		  groupList[x].name);
+	 fmt1s (temp, "<C></R>Printing Group [%.*s] to Printer",
+		groupList[x].name);
 	 mesg[0] = copyChar (temp);
 	 title = newCDKLabel (screen, CENTER, TOP,
-			      (CDK_CSTRING2) mesg, 1,
+			      (CDK_CSTRING2)mesg, 1,
 			      FALSE, FALSE);
 	 drawCDKLabel (title, FALSE);
 	 freeChar (mesg[0]);
@@ -1516,11 +1525,11 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 	 entry = newCDKEntry (screen, CENTER, 8,
 			      0, "</R>Printer Name: ",
 			      A_NORMAL,
-			      '_', vMIXED, 20, 2, 256, TRUE, FALSE);
+			      '_', vMIXED, 20, 2, MYSIZE, TRUE, FALSE);
 
 	 /* Set the printer name to the default printer. */
 	 defaultPrinter = getenv ("PRINTER");
-	 setCDKEntry (entry, defaultPrinter, 2, 256, TRUE);
+	 setCDKEntry (entry, defaultPrinter, 2, MYSIZE, TRUE);
 	 printer = copyChar (activateCDKEntry (entry, 0));
 	 destroyCDKEntry (entry);
 
@@ -1528,10 +1537,10 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 	 if (printGroup (groupList[x], "/tmp/rolodex.tmp", printer) == 0)
 	 {
 	    /* The group could not be printed. */
-	    sprintf (temp, "<C>Sorry the group '%s' could not be printed.",
-		     groupList[x].name);
+	    fmt1s (temp, "<C>Sorry the group '%.*s' could not be printed.",
+		   groupList[x].name);
 	    mesg[0] = strdup (temp);
-	    popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+	    popupLabel (screen, (CDK_CSTRING2)mesg, 1);
 	    freeChar (mesg[0]);
 	 }
 
@@ -1543,10 +1552,10 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
       else if (selectionList->selections[x] == 1)
       {
 	 /* Create a title. */
-	 sprintf (temp, "<C></R>Printing Group [%s] to File", groupList[x].name);
+	 fmt1s (temp, "<C></R>Printing Group [%.*s] to File", groupList[x].name);
 	 mesg[0] = copyChar (temp);
 	 title = newCDKLabel (screen, CENTER, TOP,
-			      (CDK_CSTRING2) mesg, 1,
+			      (CDK_CSTRING2)mesg, 1,
 			      FALSE, FALSE);
 	 drawCDKLabel (title, FALSE);
 	 freeChar (mesg[0]);
@@ -1555,7 +1564,7 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 	 entry = newCDKEntry (screen, CENTER, 8,
 			      0, "</R>Filename: ",
 			      A_NORMAL, '_', vMIXED,
-			      20, 2, 256, TRUE, FALSE);
+			      20, 2, MYSIZE, TRUE, FALSE);
 	 filename = copyChar (activateCDKEntry (entry, 0));
 	 destroyCDKEntry (entry);
 
@@ -1563,10 +1572,10 @@ void printGroupNumbers (CDKSCREEN *screen, SRolodex * groupList, int groupCount)
 	 if (printGroup (groupList[x], filename, printer) == 0)
 	 {
 	    /* The group could not be printed. */
-	    sprintf (temp, "<C>Sorry the group '%s' could not be printed.",
-		     groupList[x].name);
+	    fmt1s (temp, "<C>Sorry the group '%.*s' could not be printed.",
+		   groupList[x].name);
 	    mesg[0] = strdup (temp);
-	    popupLabel (screen, (CDK_CSTRING2) mesg, 1);
+	    popupLabel (screen, (CDK_CSTRING2)mesg, 1);
 	    freeChar (mesg[0]);
 	 }
 
@@ -1595,9 +1604,8 @@ int printGroup (SRolodex groupRecord, const char *filename, char *printer)
 #else
    uid_t uid = getuid ();
 #endif
-   char tempFilename[256], command[256];
+   char tempFilename[MYSIZE];
    SPhoneData phoneData;
-   SPhoneRecord *phoneRecord;
    int phoneCount, x;
    FILE *fd;
 
@@ -1607,7 +1615,7 @@ int printGroup (SRolodex groupRecord, const char *filename, char *printer)
    /* Create the temporary filename. */
    if (filename != 0)
    {
-      sprintf (tempFilename, "%s", filename);
+      fmt1s (tempFilename, "%.*s", filename);
    }
    else
    {
@@ -1637,7 +1645,7 @@ int printGroup (SRolodex groupRecord, const char *filename, char *printer)
 	    "==============================================================================\n");
    for (x = 0; x < phoneCount; x++)
    {
-      phoneRecord = &phoneData.record[x];
+      SPhoneRecord *phoneRecord = &phoneData.record[x];
       fprintf (fd, "Name        : %s\n", phoneRecord->name);
       fprintf (fd, "Phone Number: %s (%s)\n", phoneRecord->phoneNumber,
 	       GLineType[phoneRecord->lineType]);
@@ -1654,6 +1662,7 @@ int printGroup (SRolodex groupRecord, const char *filename, char *printer)
    /* Determine if the information is going to a file or printer. */
    if (printer != 0)
    {
+      char command[MYSIZE];
       /* Print the file to the given printer. */
       sprintf (command, "lpr -P%s %s", printer, tempFilename);
       system (command);
@@ -1705,7 +1714,7 @@ int insertPhoneEntryCB (EObjectType cdkType GCC_UNUSED, void *object, void
    CDKSCROLL *scrollp = (CDKSCROLL *)object;
    SPhoneData *phoneData = (SPhoneData *) clientData;
    SPhoneRecord *phoneRecord = &phoneData->record[phoneData->recordCount];
-   char temp[256];
+   char temp[MYSIZE];
 
    /* Make the scrolling list disappear. */
    eraseCDKScroll (scrollp);
@@ -1732,7 +1741,7 @@ int deletePhoneEntryCB (EObjectType cdkType GCC_UNUSED, void *object, void
    CDKSCROLL *scrollp = (CDKSCROLL *)object;
    SPhoneData *phoneData = (SPhoneData *) clientData;
    const char *mesg[3];
-   char temp[256], *hold;
+   char temp[MYSIZE], *hold;
    const char *buttons[] =
    {
       "</B/16><No>",
@@ -1748,19 +1757,19 @@ int deletePhoneEntryCB (EObjectType cdkType GCC_UNUSED, void *object, void
    if (scrollp->listSize == 0)
    {
       mesg[0] = "There are no more numbers to delete.";
-      popupLabel (ScreenOf (scrollp), (CDK_CSTRING2) mesg, 1);
+      popupLabel (ScreenOf (scrollp), (CDK_CSTRING2)mesg, 1);
       return (FALSE);
    }
 
    /* Ask the user if they really want to delete the listing. */
    mesg[0] = "<C>Do you really want to delete the phone entry";
    hold = chtype2Char (scrollp->item[scrollp->currentItem]);
-   sprintf (temp, "<C></B/16>%s", hold);
+   fmt1s (temp, "<C></B/16>%.*s", hold);
    freeChar (hold);
    mesg[1] = copyChar (temp);
    if (popupDialog (ScreenOf (scrollp),
-		    (CDK_CSTRING2) mesg, 2,
-		    (CDK_CSTRING2) buttons, 2) == 1)
+		    (CDK_CSTRING2)mesg, 2,
+		    (CDK_CSTRING2)buttons, 2) == 1)
    {
       /* Remove the item from the phone data record. */
       for (x = position; x < phoneData->recordCount - 1; x++)
@@ -1812,7 +1821,7 @@ int phoneEntryHelpCB (EObjectType cdkType GCC_UNUSED, void *object, void
    sprintf (temp, "<B=?     > Pops up this help window.");
    mesg[4] = copyChar (temp);
 
-   popupLabel (ScreenOf (scrollp), (CDK_CSTRING2) mesg, 5);
+   popupLabel (ScreenOf (scrollp), (CDK_CSTRING2)mesg, 5);
 
    freeCharList (mesg, 5);
    return (FALSE);
@@ -1838,7 +1847,7 @@ int helpCB (EObjectType cdkType GCC_UNUSED, void *object, void *clientData
    /* Create the help title. */
    name = chtype2Char (menu->sublist[menuList][submenuList]);
    stripWhiteSpace (vBOTH, name);
-   sprintf (temp, "<C></R>Help<!R> </U>%s<!U>", name);
+   fmt1s (temp, "<C></R>Help<!R> </U>%.*s<!U>", name);
    mesg[0] = msg_0 = copyChar (temp);
    freeChar (name);
 
@@ -1888,7 +1897,7 @@ int helpCB (EObjectType cdkType GCC_UNUSED, void *object, void *clientData
    }
 
    /* Pop up the message. */
-   popupLabel (ScreenOf (menu), (CDK_CSTRING2) mesg, 2);
+   popupLabel (ScreenOf (menu), (CDK_CSTRING2)mesg, 2);
    freeChar (msg_0);
 
    /* Redraw the submenu window. */
@@ -1912,17 +1921,17 @@ int groupInfoCB (EObjectType cdkType GCC_UNUSED, void *object, void
    /* Create the message to be displayed. */
    mesg[0] = copyChar ("<C></U>Detailed Group Information.");
 
-   sprintf (temp, "</R>Group Name         <!R> %s", groupList[selection].name);
+   fmt1s (temp, "</R>Group Name         <!R> %.*s", groupList[selection].name);
    mesg[1] = copyChar (temp);
 
-   sprintf (temp, "</R>Group Description  <!R> %s", groupList[selection].desc);
+   fmt1s (temp, "</R>Group Description  <!R> %.*s", groupList[selection].desc);
    mesg[2] = copyChar (temp);
 
-   sprintf (temp, "</R>Group Database File<!R> %s", groupList[selection].dbm);
+   fmt1s (temp, "</R>Group Database File<!R> %.*s", groupList[selection].dbm);
    mesg[3] = copyChar (temp);
 
    /* Display the message. */
-   popupLabel (ScreenOf (scrollp), (CDK_CSTRING2) mesg, 4);
+   popupLabel (ScreenOf (scrollp), (CDK_CSTRING2)mesg, 4);
    freeCharList (mesg, 4);
 
    /* Redraw the scrolling list. */
