@@ -1,4 +1,4 @@
-/* $Id: vinstall.c,v 1.15 2011/05/15 20:38:16 tom Exp $ */
+/* $Id: vinstall.c,v 1.20 2016/11/20 20:40:00 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -13,7 +13,7 @@ char *XCursesProgramName = "vinstall";
  */
 
 /* Declare global types and prototypes. */
-static char *FPUsage = "-f filename [-s source directory] [-d destination directory] [-t title] [-o Output file] [-q]";
+static const char *FPUsage = "-f filename [-s source directory] [-d destination directory] [-t title] [-o Output file] [-q]";
 
 typedef enum
 {
@@ -46,10 +46,11 @@ int main (int argc, char **argv)
    int quiet                    = FALSE;
    int errors                   = 0;
    int sWindowHeight            = 0;
-   char *titleMessage[10], **fileList = 0, *mesg[20];
+   char *titleMessage[10];
+   char **fileList              = 0;
+   const char *mesg[20];
    char oldPath[512], newPath[512], temp[2000];
-   char **files;
-   int count, chunks, ret, x;
+   int count, ret, x;
 
    /* Parse up the command line. */
    while (1)
@@ -119,7 +120,7 @@ int main (int argc, char **argv)
    initCDKColor ();
 
    /* Create the title label. */
-   titleMessage[0] = "<C></32/B><#HL(30)>";
+   titleMessage[0] = copyChar ("<C></32/B><#HL(30)>");
    if (title == 0)
    {
       sprintf (temp, "<C></32/B>CDK Installer");
@@ -129,10 +130,11 @@ int main (int argc, char **argv)
       sprintf (temp, "<C></32/B>%.256s", title);
    }
    titleMessage[1] = copyChar (temp);
-   titleMessage[2] = "<C></32/B><#HL(30)>";
+   titleMessage[2] = copyChar ("<C></32/B><#HL(30)>");
    titleWin = newCDKLabel (cdkScreen, CENTER, TOP,
-			   titleMessage, 3, FALSE, FALSE);
-   freeChar (titleMessage[1]);
+			   (CDK_CSTRING2)titleMessage, 3,
+			   FALSE, FALSE);
+   freeCharList (titleMessage, 3);
 
    /* Allow them to change the install directory. */
    if (sourcePath == 0)
@@ -251,13 +253,16 @@ int main (int argc, char **argv)
    /* Start copying the files. */
    for (x = 0; x < count; x++)
    {
+      char **files;
+      int chunks;
+
       /*
        * If the 'file' list file has 2 columns, the first is
        * the source filename, the second being the destination
        * filename.
        */
       files = CDKsplitString (fileList[x], ' ');
-      chunks = (int)CDKcountStrings (files);
+      chunks = (int)CDKcountStrings ((CDK_CSTRING2)files);
       if (chunks == 2)
       {
 	 /* Create the correct paths. */
@@ -312,8 +317,12 @@ int main (int argc, char **argv)
    if (errors != 0)
    {
       /* Create the information for the dialog box. */
-      char *buttons[] =
-      {"Look At Errors Now", "Save Output To A File", "Ignore Errors"};
+      const char *buttons[] =
+      {
+	 "Look At Errors Now",
+	 "Save Output To A File",
+	 "Ignore Errors"
+      };
       mesg[0] = "<C>There were errors in the installation.";
       mesg[1] = "<C>If you want, you may scroll through the";
       mesg[2] = "<C>messages of the scrolling window to see";
@@ -324,14 +333,16 @@ int main (int argc, char **argv)
       mesg[7] = "<C>history at a later date.";
 
       /* Popup the dialog box. */
-      ret = popupDialog (cdkScreen, mesg, 8, buttons, 3);
+      ret = popupDialog (cdkScreen,
+			 (CDK_CSTRING2)mesg, 8,
+			 (CDK_CSTRING2)buttons, 3);
       if (ret == 0)
       {
 	 activateCDKSwindow (installOutput, 0);
       }
       else if (ret == 1)
       {
-	 injectCDKSwindow (installOutput, 's');
+	 (void)injectCDKSwindow (installOutput, 's');
       }
    }
    else
@@ -349,14 +360,19 @@ int main (int argc, char **argv)
 	 /* Ask them if they want to save the output of the scrolling window. */
 	 if (quiet == FALSE)
 	 {
-	    char *buttons[] =
-	    {"No", "Yes"};
+	    const char *buttons[] =
+	    {
+	       "No",
+	       "Yes"
+	    };
 	    mesg[0] = "<C>Do you want to save the output of the";
 	    mesg[1] = "<C>scrolling window to a file?";
 
-	    if (popupDialog (cdkScreen, mesg, 2, buttons, 2) == 1)
+	    if (popupDialog (cdkScreen,
+			     (CDK_CSTRING2)mesg, 2,
+			     (CDK_CSTRING2)buttons, 2) == 1)
 	    {
-	       injectCDKSwindow (installOutput, 's');
+	       (void)injectCDKSwindow (installOutput, 's');
 	    }
 	 }
       }
@@ -419,15 +435,11 @@ static ECopyFile copyFile (CDKSCREEN *cdkScreen GCC_UNUSED, char *src, char *des
  */
 static int verifyDirectory (CDKSCREEN *cdkScreen, char *directory)
 {
-   char *buttons[] =
-   {"Yes", "No"};
    int status = 0;
 #if !defined (__MINGW32__)
    mode_t dirMode = S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH;
 #endif
    struct stat fileStat;
-   char *mesg[10];
-   char *error[10];
    char temp[512];
 
    /* Stat the directory. */
@@ -436,15 +448,25 @@ static int verifyDirectory (CDKSCREEN *cdkScreen, char *directory)
       /* The directory does not exist. */
       if (errno == ENOENT)
       {
+	 const char *buttons[] =
+	 {
+	    "Yes",
+	    "No"
+	 };
+	 const char *mesg[10];
+	 char *error[10];
+
 	 /* Create the question. */
 	 mesg[0] = "<C>The directory ";
 	 sprintf (temp, "<C>%.256s", directory);
-	 mesg[1] = copyChar (temp);
+	 mesg[1] = temp;
 	 mesg[2] = "<C>Does not exist. Do you want to";
 	 mesg[3] = "<C>create it?";
 
 	 /* Ask them if they want to create the directory. */
-	 if (popupDialog (cdkScreen, mesg, 4, buttons, 2) == 0)
+	 if (popupDialog (cdkScreen,
+			  (CDK_CSTRING2)mesg, 4,
+			  (CDK_CSTRING2)buttons, 2) == 0)
 	 {
 	    /* Create the directory. */
 #if defined (__MINGW32__)
@@ -454,7 +476,7 @@ static int verifyDirectory (CDKSCREEN *cdkScreen, char *directory)
 #endif
 	    {
 	       /* Create the error message. */
-	       error[0] = "<C>Could not create the directory";
+	       error[0] = copyChar ("<C>Could not create the directory");
 	       sprintf (temp, "<C>%.256s", directory);
 	       error[1] = copyChar (temp);
 
@@ -466,28 +488,23 @@ static int verifyDirectory (CDKSCREEN *cdkScreen, char *directory)
 	       error[2] = copyChar (temp);
 
 	       /* Pop up the error message. */
-	       popupLabel (cdkScreen, error, 3);
+	       popupLabel (cdkScreen, (CDK_CSTRING2)error, 3);
 
-	       /* Clean up and set the error status. */
-	       freeChar (error[1]);
-	       freeChar (error[2]);
+	       freeCharList (error, 3);
 	       status = -1;
 	    }
 	 }
 	 else
 	 {
 	    /* Create the message. */
-	    error[0] = "<C>Installation aborted.";
+	    error[0] = copyChar ("<C>Installation aborted.");
 
 	    /* Pop up the error message. */
-	    popupLabel (cdkScreen, error, 1);
+	    popupLabel (cdkScreen, (CDK_CSTRING2)error, 1);
 
-	    /* Set the exit status. */
+	    freeCharList (error, 1);
 	    status = -1;
 	 }
-
-	 /* Clean up. */
-	 freeChar (mesg[1]);
       }
    }
    return status;
